/*
 * File: AirportCodes.js
 * ---------------------
 * This program looks up three-letter airport codes in a map object.
 */

"use strict";

/* Main program */

function AirportCodes() {
	let callback = function(text) {
		let lines = JSFileChooser.convertToLineArray(text);
		let airportCodes = parseAirportCodes(lines);
		publishAllAirportCodes(airportCodes);
	};
	JSFileChooser.chooseTextFile(callback);
}

/*
 * Accepts an array of lines trusted to be the contents of
 * a well-formed airport codes file, and then creates a map
 * linking each airport code with the corresponding city name.
 * Each line in the data file must consist of a three-letter
 * code, an equal sign, and the city name for that airport.
 */
function parseAirportCodes(lines) {
   let airportCodes = {};
   let line = lines.shift();
   while (line !== undefined) {
    	let ep = line.indexOf("=");
     	let code = line.substring(0, ep).trim();
     	let city = line.substring(ep + 1).trim();
     	airportCodes[code] = city;
     	line = lines.shift();
   }
   return airportCodes;
}

/**
 * Lists all of the airport codes and the the cities they serve.
 */
function publishAllAirportCodes(airportCodes) {
   for (let code in airportCodes) {
      console.log(code + " serves to greater " + airportCodes[code] + " area.");
   }
}
